## About
This is a toolkit for making machine learning with Scikit-learn and Keras easier.
It wraps functionality in Scikit-learn and Keras and other useful packages into simple function calls.

## Install
Install with:

<code>pip install mltlk</code>

## How to use
Check the notebooks for examples of how to use the toolkit.
